################################################################################
# Model cooling of coffee in a cup with a simple lumped model
#
#    mc cc dTc/dt = h A (Tout - Tc)
#
# where: mc = mass of coffee in cup
#        cc = heat capacity of coffee
#        Tc = temperature of coffee
#      Tout = temperature of environment
#         h = heat transfer coefficient
#         A = surface area of coffee cup (including upper surface)
#
#  Note that dividing through by mc cc gives the equation implemented:
#
#         dTc/dt = h A / (mc cc) (Tout - Tc)
#

import IVP    

################################################################################
## Coffee class definition (a subclass of IVP)
################################################################################

class CoffeeIVP(IVP.IVP):

    def evalf(self, Tc, t):
        """
        
        Args:
            Tc (float list): current temperature of coffee.
            t (float): current time
    
        Returns:
            f (float list): forcing
    
        """
        
        mc   = self.get_p('mc')
        cc   = self.get_p('cc')
        h    = self.get_p('h')
        A    = self.get_p('A')
        Tout = self.get_p('Tout')
    
        f = h*A/(mc*cc)*(Tout - Tc[0])
            
        return [f]  